<?php

/*
 * Plugin Name: EngageBay WooCommerce Addon
 * Plugin URI: http://woocommerce.com/products/woocommerce-extension/
 * Description: Using EngageBay, automate all the manual and tedious tasks on your WooCommerce store and focus more on your business.
 * Version: 1.6
 * Author: engagebay
 * Author URI: http://engagebay.com/
 * Developer: EngageBay
 * Developer URI: http://engagebay.com/
 * Text Domain: woocommerce-extension
 * Domain Path: /languages.
 *
 * WC requires at least: 2.2
 * WC tested up to: 5.3.2
 *
 * Copyright: © 2009-2015 WooCommerce.
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 */
if (!defined('ABSPATH')) {
    exit('You are not allowed to access this file directly.');
}

/*
 * Check if WooCommerce is active
 **/
if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
    set_time_limit(0);
    function engagebay_wc_root_url($append = false)
    {
        $base_url = plugin_dir_url(__FILE__);

        return $append ? $base_url.$append : $base_url;
    }

    function engagebay_wc_root_dir($append = false)
    {
        $base_dir = plugin_dir_path(__FILE__);

        return $append ? $base_dir.$append : $base_dir;
    }

    add_action('admin_menu', 'register_engagebay_wc_submenu_page', 99);

    function register_engagebay_wc_submenu_page()
    {
        add_submenu_page('woocommerce', 'EngageBay WC', 'EngageBay WooCommerce', 'manage_options', 'engagebay-wc', 'engagebay_wc_callback');
    }

    function engagebay_wc_callback()
    {
        if (get_option('engagebay_wc_signed_in') == true) {
            engagebay_wc_settings_page();
        } else {
            engagebay_wc_login_page();
        }
    }

    function engagebay_wc_css()
    {
        wp_enqueue_style('engagebay-wc-software', engagebay_wc_root_url('assets/css/styles.css'));
    }

    add_action('admin_init', 'engagebay_wc_register_settings');
    function engagebay_wc_register_settings()
    {
        register_setting('engagebay-wc-settings-group', 'engagebay-wc-sync-customers');
        register_setting('engagebay-wc-settings-group', 'engagebay-wc-sync-orders');
        register_setting('engagebay-wc-settings-group', 'engagebay-wc-enable-webpopups');
        add_action('admin_enqueue_scripts', 'engagebay_wc_engagebay_sync');
    }

    function engagebay_wc_login_page()
    {
        if (isset($_GET['tab']) && $_GET['tab'] == 'register') {
            engagebay_wc_registration_page();

            return;
        }

        engagebay_wc_css();
        $deprecated = null;
        $autoload = 'no';

        if (isset($_POST['email'])) {
            $email = sanitize_email($_POST['email']);
        }
        if (isset($email) && $email) {
            $email = sanitize_email($_POST['email']);
            @$rest_api = sanitize_text_field($_POST['rest_api']);
            $password = sanitize_text_field($_POST['password']);
            $api_url = 'https://app.engagebay.com/rest/api/login/get-domain';
            $request = wp_remote_post($api_url, array(
                    'method' => 'post',
                    'body' => array('email' => $email, 'password' => $password, 'source' => 'WORDPRESS'),
                )
            );
            $result = wp_remote_retrieve_body($request);

            if (version_compare(PHP_VERSION, '5.4.0', '>=') && !(defined('JSON_C_VERSION') && PHP_INT_SIZE > 4)) {
                $result = json_decode($result, true, 512, JSON_BIGINT_AS_STRING);
            } else {
                $result = json_decode($result, true);
            }

            $domain = $result['domain_name'];
            $js_api = $result['api_key']['js_API_Key'];
            $rest_api = $result['api_key']['rest_API_Key'];
            if (isset($result['type']) && $result['type'] == 'ACCOUNT_NOT_ACTIVATED') {
                wp_redirect('admin.php?page=engagebay-wc&tab=edit&error=account_not_activated&email='.$email);
                $errors = 'Invalid details. Please provide valid details and try again';
            } elseif ($domain == '' && $rest_api == '') {
                wp_redirect('admin.php?page=engagebay-wc&tab=edit&error=invalid');
                $errors = 'Invalid details. Please provide valid details and try again';
            } else {
                if (get_option('engagebay_wc_settings_password') !== false) {
                    update_option('engagebay_wc_settings_password', $password);
                } else {
                    add_option('engagebay_wc_settings_password', $password, $deprecated, $autoload);
                }

                if (get_option('engagebay_wc_settings_rest_api') !== false) {
                    update_option('engagebay_wc_settings_rest_api', $rest_api);
                } else {
                    add_option('engagebay_wc_settings_rest_api', $rest_api, $deprecated, $autoload);
                }

                if (get_option('engagebay_wc_settings_domain') !== false) {
                    update_option('engagebay_wc_settings_domain', $domain);
                } else {
                    add_option('engagebay_wc_settings_domain', $domain, $deprecated, $autoload);
                }

                if (get_option('engagebay_wc_settings_js_api') !== false) {
                    update_option('engagebay_wc_settings_js_api', $js_api);
                } else {
                    add_option('engagebay_wc_settings_js_api', $js_api, $deprecated, $autoload);
                }

                if (get_option('engagebay_wc_settings_email') !== false) {
                    update_option('engagebay_wc_settings_email', $email);
                } else {
                    add_option('engagebay_wc_settings_email', $email, $deprecated, $autoload);
                }

                $sucesserrors = 'SucessFully Verified the domain';
            }
        }
        $rest_api = (sanitize_text_field(get_option('engagebay_wc_settings_rest_api')));
        $domain = (sanitize_text_field(get_option('engagebay_wc_settings_domain')));
        $email = (sanitize_email(get_option('engagebay_wc_settings_email')));
        if (isset($_GET['tab'])) {
            $tab = $_GET['tab'];
        } ?>
        <div class="be-wrapper be-login">
            <div class="be-content">
                <div class="main-content container-fluid">
                    <?php  if (!isset($sucesserrors) && ($email == '' || (isset($tab) && $tab == 'edit') || $rest_api == '')) {
            ?>

                    <div class="splash-container">
                        <div class="panel">
                            <?php if ((isset($errors) && $errors)) {
                echo '<div id="error_message">'.$errors.'<br/></div>';
            } elseif (isset($_GET['error']) && $_GET['error'] == 'invalid') {
                echo '<div id="error_message">Invalid details. Please provide valid details and try again<br/></div>';
            } elseif (isset($_GET['error']) && $_GET['error'] == 'account_not_activated') {
                echo '<div id="error_message">Your account is not activated. A confirmation email was sent to '.$_GET['email'].'<br/></div>';
            } ?>
                            <?php if (isset($sucesserrors) && $sucesserrors) {
                //echo '<div id="success_message">' . $sucesserrors . '<br/></div>';
                wp_redirect(engagebay_wc_logged_in_page());
            } elseif (get_option('engagebay_wc_settings_rest_api') !== false) {
                if (!isset($tab)) {
                    echo '<div id="success_message">You are Connected with EngageBay</div>';
                }
            } ?>
                            <div class="panel-heading text-center">
                                <?php echo "<img src='".engagebay_wc_root_url('assets/images/engagebay.png')."' width='170' title='EngageBay logo'/>"; ?>
                                <h4>EngageBay Login</h4>
                            </div>
                            <div class="panel-body">
                                <form name="loginForm" id="loginForm" class="" action="admin.php?page=engagebay-wc" method="post">

                                    <div class="form-group">
                                        <div class="">
                                            <input class="form-control" type="email" pattern="[a-z0-9._%+-]+@[a-z0-9.-]+\.[a-z]{2,5}$" name="email" autocomplete="off" placeholder="Work Email" value="<?php echo $email; ?>" required>
                                        </div>
                                    </div>
                                    <div class="form-group">
                                        <div class="">
                                            <input class="form-control" type="password" name="password"  placeholder="Password" required>
                                        </div>
                                    </div>
                                    <div class="form-group">
                                        <div class="xs-pt-20 md-pt-20">
                                            <div class="login-submit xs-m-0 md-p-0">
                                                <button class="btn btn-success btn-xl" type="submit">LOGIN
                                                    <?php echo "<img src='".engagebay_wc_root_url('assets/images/loader.gif')."' 
                      style='display: none;' id='gif' title='Landing Pages'/>"; ?>
                                            </div>
                                        </div>
                                    </div>

                                </form>
                            </div>
                        </div>

                        <div class="splash-footer">
                            Forgot <a href="https://app.engagebay.com/forgot-password" target="_blank" class="text-info">Password?</a>
                        </div>
                        <div class="alert text-center">
                            <div>
                                <div>Don't have an account? <a target="_blank" href="https://app.engagebay.com/signup" ><?php _e('Sign Up', 'sandbox'); ?></a>
                                </div>
                            </div>
                        </div>


                    </div>
                </div>

                <?php
        } elseif ($email != false) {
            wp_redirect(engagebay_wc_logged_in_page()); ?>

            </div>


            <?php
        } else {
            //wp_redirect(engagebay_wc_logged_in_page());
        } ?>
        </div>
        </div>
        </div>

        <?php
    }

    function engagebay_wc_registration_page()
    {
        engagebay_wc_css();
        if (isset($_POST['email'])) {
            $email = sanitize_email($_POST['email']);
        }
        if (isset($email) && $email) {
            $engagebay_array['email'] = sanitize_email($_POST['email']);
            $engagebay_array['name'] = sanitize_text_field($_POST['name']);
            $engagebay_array['website'] = sanitize_text_field($_POST['website']);
            $engagebay_array['password'] = sanitize_text_field($_POST['password']);
            $engagebay_array['command'] = sanitize_text_field($_POST['command']);
            $engagebay_array['timeZoneId'] = sanitize_text_field($_POST['timeZoneId']);
            $engagebay_array['source'] = 'WORDPRESS';

            $api_url = 'https://app.engagebay.com/rest/api/signup/signup-user';
            $request = wp_remote_post($api_url, array(
                    'method' => 'post',
                    'timeout' => 40,
                    'httpversion' => '1.0',
                    'blocking' => true,
                    'body' => $engagebay_array,
                )
            );
            $result = wp_remote_retrieve_body($request);
            $resultString = $result;

            if (version_compare(PHP_VERSION, '5.4.0', '>=') && !(defined('JSON_C_VERSION') && PHP_INT_SIZE > 4)) {
                $result = json_decode($result, true, 512, JSON_BIGINT_AS_STRING);
            } else {
                $result = json_decode($result, true);
            }

            $domain = $result['domain_name'];
            $js_api = $result['api_key']['js_API_Key'];
            $rest_api = $result['api_key']['rest_API_Key'];
            $email = sanitize_email($_POST['email']);
            $password = sanitize_text_field($_POST['password']);
            if ($domain == '') {
                $errors = $resultString;
            } else {
                if (get_option('engagebay_wc_settings_password') !== false) {
                    update_option('engagebay_wc_settings_password', $password);
                } else {
                    add_option('engagebay_wc_settings_password', $password, $deprecated, $autoload);
                }

                if (get_option('engagebay_wc_settings_rest_api') !== false) {
                    update_option('engagebay_wc_settings_rest_api', $rest_api);
                } else {
                    add_option('engagebay_wc_settings_rest_api', $rest_api, $deprecated, $autoload);
                }

                if (get_option('engagebay_wc_settings_domain') !== false) {
                    update_option('engagebay_wc_settings_domain', $domain);
                } else {
                    add_option('engagebay_wc_settings_domain', $domain, $deprecated, $autoload);
                }

                if (get_option('engagebay_wc_settings_js_api') !== false) {
                    update_option('engagebay_wc_settings_js_api', $js_api);
                } else {
                    add_option('engagebay_wc_settings_js_api', $js_api, $deprecated, $autoload);
                }

                if (get_option('engagebay_wc_settings_email') !== false) {
                    update_option('engagebay_wc_settings_email', $email);
                } else {
                    add_option('engagebay_wc_settings_email', $email, $deprecated, $autoload);
                }

                $sucesserrors = 'SucessFully Registered';
            }
        } ?>

        <div class="be-wrapper be-login">
            <div class="be-content">
                <div class="main-content container-fluid">
                    <div class="splash-container">
                        <div class="panel">
                            <div class="panel-heading">

                                <?php echo "<img src='".engagebay_wc_root_url('assets/images/engagebay.png', __FILE__)."' width='170' title='Enage bay logo'/>"; ?>
                                <h4>
                                    Get Started for <strong>FREE</strong>
                                </h4>
                            </div>
                            <?php if (!isset($sucesserrors)) {
            ?>
                            <div class="panel-body">
                                <?php
                                if (isset($errors)) {
                                    ?>
                                    <div class="alert alert-danger">
                                        <strong><?php echo $errors; ?> </strong>
                                        <?php echo $result; ?>
                                    </div>
                                <?php
                                } ?>
                                <form id="loginForm" name="loginForm" method="POST">

                                    <input type="hidden" name="command" value="signup">
                                    <input type="hidden" name="timeZoneId" value="330">
                                    <input type="hidden" name="referral_user_id" value="">
                                    <div class="form-group">
                                        <div class="">
                                            <input class="form-control" type="name" name="name" autocomplete="name" placeholder="Name" title="Name should be between 1-30 characters in length. Both letters and numbers are allowed but it should start with a letter. Cannot contain special characters." minlength="1" maxlength="30" required="" pattern="^[a-zA-Z][a-zA-Z0-9 ]{1,30}$">
                                        </div>
                                    </div>
                                    <div class="form-group">
                                        <div class="position-relative">
                                            <input class="form-control user-email-field" id="register_email" type="email" name="email" required autocapitalize="off" minlength="6" maxlength="50" placeholder="Work Email" oninvalid="set_custom_validate(this);" oninput="reset_custom_validate(this);"  pattern="^.+@((?!gmail.com)(?!yahoo.com)(?!yahoo.in)(?!hotmail.com)(?!fastmail.com).)+\..+$" data-pattern-mismatch-error="Please use your business email address to sign up" value="">
                                            <span id="validEmail" class="validation-result">
                   </span>
                                        </div>
                                    </div>
                                    <div class="form-group">
                                        <div class="">
                                            <input class="form-control" type="url" name="website" autocomplete="url" placeholder="Website URL" value=""  minlength="3" maxlength="50" required="" pattern="^(https?://)?([a-zA-Z0-9]([a-zA-Z0-9\-]{0,61}[a-zA-Z0-9])?\.)+[a-zA-Z]{2,6}$">
                                        </div>
                                    </div>
                                    <div class="form-group">
                                        <div class="">
                                            <input class="form-control" type="password" name="password" pattern=".{4,20}" autocomplete="off" placeholder="Password" title="Enter at least 4 characters." required="">
                                        </div>
                                    </div>
                                    <div class="form-group">
                                        <div class="xs-pt-20 md-pt-20">
                                            <div class="login-submit xs-m-0 md-p-0">
                                                <button class="btn btn-success btn-xl" type="submit">
                                                    SIGN UP
                                                    <?php echo "<img src='".engagebay_wc_root_url('assets/images/loader.gif', __FILE__)."' 
                      style='display: none;' id='gif' title='Landing Pages'/>"; ?>
                                                </button>
                                            </div>
                                        </div>
                                    </div>
                                </form>
                            </div>

                        </div>
                        <div class="splash-footer">
                            Forgot <a href="https://app.engagebay.com/forgot-password" target="_blank" class="text-info">Password?</a>
                        </div>
                        <div class="splash-footer alert">
                            Already have an account? <a href="?page=engagebay-wc"  ><?php _e('Sign In', 'sandbox'); ?></a>
                        </div>
                        <?php
        } else {
            ?>
                            <div class="panel-body">
                                <div class="alert alert-success fade in alert-dismissible">
                                    <strong>Successfully!</strong>  Registered.
                                </div>
                            </div>
                            <?php
                            engagebay_wc_engagebay_sync();
        } ?>

                    </div>
                </div>
            </div>
        </div>
        <?php
    }

    function engagebay_wc_logged_in_page()
    {
        echo $settings_page = '<div style="height:600px;background:#f1f1f1">';
        $email = get_option('engagebay_wc_settings_email');
        $password = get_option('engagebay_wc_settings_password');
        $api_url = 'https://app.engagebay.com/rest/api/login/get-domain';
        $request = wp_remote_post($api_url, array(
                'method' => 'post',
                'body' => array('email' => $email, 'password' => $password, 'source' => 'WORDPRESS'),
            )
        );
        $result = wp_remote_retrieve_body($request);
        if (version_compare(PHP_VERSION, '5.4.0', '>=') && !(defined('JSON_C_VERSION') && PHP_INT_SIZE > 4)) {
            $result = json_decode($result, true, 512, JSON_BIGINT_AS_STRING);
        } else {
            $result = json_decode($result, true);
        }

        if (isset($result['is_verified']) && !$result['is_verified']) {
            echo "<div class='notice notice-warning'> Your domain is not verified. Please verify your domain</div>";
        }

        echo $settings_page .= '<form action="options.php" method="POST" style="margin-left: 25px; margin-top: 20px; margin-right: 20px;" id="enagebay_wc_settings_form">';
        echo $settings_page .= engagebay_wc_get_view_template('engagebay-wc-settings.tpl.php');
    }

    function engagebay_wc_get_view_template($template_name)
    {
        global $wpdb;

        $template_content = false;
        $template_path = engagebay_wc_root_dir('views/').$template_name;

        // $args = array(
        //     'role' => 'Customer',
        // );
        $users = get_users([]);

        $orders_count = wc_orders_count('processing') + wc_orders_count('completed') + wc_orders_count('pending') + wc_orders_count('on-hold') + wc_orders_count('cancelled') + wc_orders_count('refunded') + wc_orders_count('failed');

        $products = $wpdb->get_results('SELECT count(distinct(o.order_item_name)) as `products_count` FROM `wp_woocommerce_order_items` `o` JOIN `wp_posts` `p` ON o.order_id = p.ID WHERE o.order_item_type="line_item" AND p.post_status!="trash"');

        if (file_exists($template_path)) {
            $search_replace = array(
                "<?php if(!defined( 'ABSPATH')) exit;?>" => '',
                '{plugin_url}' => engagebay_wc_root_url(),
                '{site_url}' => get_site_url(),
                '{engagebay_logo}' => engagebay_wc_root_url('assets/images/engagebay.png'),
                '{register_settings_fields}' => settings_fields('engagebay-wc-settings-group'),
                '{sync_customers}' => get_option('engagebay-wc-sync-customers') == 'on' ? 'checked' : 'unchecked',
                '{sync_orders}' => get_option('engagebay-wc-sync-orders') == 'on' ? 'checked' : 'unchecked',
                '{enable_webpopups}' => get_option('engagebay-wc-enable-webpopups') == 'on' ? 'checked' : 'unchecked',
                '{engagebay_domain}' => get_option('engagebay_wc_settings_domain'),
                '{customers_count}' => count($users),
                '{orders_count}' => $orders_count,
                '{products_count}' => $products[0]->products_count,
                '{enable_import_customers}' => get_option('engagebay-wc-import-contacts') == 'on' ? 'checked' : 'unchecked',
                '{enable_import_orders}' => get_option('engagebay-wc-import-orders') == 'on' ? 'checked' : 'unchecked',
                '{enable_import_products}' => get_option('engagebay-wc-import-products') == 'on' ? 'checked' : 'unchecked',
                '{loader}' => engagebay_wc_root_url('assets/images/loading.gif'),
                '{sync_label}' => 'Sync',
            );

            $search = array_keys($search_replace);
            $replace = array_values($search_replace);

            $template_content = str_replace($search, $replace, file_get_contents($template_path));
        }

        return $template_content;
    }

    require dirname(__FILE__).DIRECTORY_SEPARATOR.'includes'.DIRECTORY_SEPARATOR.'engagebay_wc_rest.php';
    require dirname(__FILE__).DIRECTORY_SEPARATOR.'includes'.DIRECTORY_SEPARATOR.'engagebay_wc_core.php';

    $IS_SYNC_CUSTOMERS = get_option('engagebay-wc-sync-customers');
    $IS_SYNC_ORDERS = get_option('engagebay-wc-sync-orders');
    $IS_ENABLE_WEBPOPUPS = get_option('engagebay-wc-enable-webpopups');

    if ($IS_SYNC_CUSTOMERS) {
        add_action('woocommerce_created_customer', 'engagebay_wc_created_customer', 10, 3);
        add_action('woocommerce_customer_object_updated_props', 'engagebay_wc_updated_customer', 10, 4);
    }

    if ($IS_SYNC_ORDERS) {
        add_action('woocommerce_new_order', 'engagebay_wc_new_order', 10, 1);
        add_action('woocommerce_checkout_order_processed', 'engagebay_wc_order_processed', 10, 3);
        add_action('woocommerce_order_status_changed', 'engagebay_wc_order_status_changed');
        add_action('woocommerce_new_customer_note', 'engagebay_wc_new_customer_note');
    }

    if ($IS_ENABLE_WEBPOPUPS) {
        add_action('wp_footer', 'engagebay_wc_script');
    }

    // add_action('wp_enqueue_scripts','engagebay_wc_engagebay_sync');

    function engagebay_wc_engagebay_sync()
    {
        wp_enqueue_script('engagebay_wc_engagebay_sync', plugins_url('assets/js/sync.js', __FILE__));
        wp_localize_script('engagebay_wc_engagebay_sync', 'ajax_url',
                            array(
                                'url' => admin_url('admin-ajax.php'),
                            )
    );
    }

    function remove_footer_admin()
    {
        echo '<span id="footer-thankyou">Visit our Website <a href="http://www.engagebay.com" target="_blank">EngageBay</a></span>';
    }

    add_filter('admin_footer_text', 'remove_footer_admin');

    function engagebay_wc_ajax_callback()
    {
        //Get the post data
        $import_contacts = $_POST['engagebay_wc_import_contacts'];
        $import_orders = $_POST['engagebay_wc_import_orders'];
        $import_products = $_POST['engagebay_wc_import_products'];

        if (get_option('engagebay-wc-import-contacts') !== false) {
            update_option('engagebay-wc-import-contacts', $import_contacts);
        } else {
            add_option('engagebay-wc-import-contacts', $import_contacts, $deprecated, $autoload);
        }

        if (get_option('engagebay-wc-import-orders') !== false) {
            update_option('engagebay-wc-import-orders', $import_orders);
        } else {
            add_option('engagebay-wc-import-orders', $import_orders, $deprecated, $autoload);
        }

        if (get_option('engagebay-wc-import-products') !== false) {
            update_option('engagebay-wc-import-products', $import_products);
        } else {
            add_option('engagebay-wc-import-products', $import_products, $deprecated, $autoload);
        }

        $users = get_users([]);
        $args = array(
            'limit' => -1,
        );
        $orders = wc_get_orders($args);

        if ($import_contacts == 'on') {
            engagebay_wc_sync_users($users);
        }

        if ($import_orders == 'on') {
            engagebay_wc_sync_orders($orders);
        }

        echo 'success';
        //Make sure you die when finished doing ajax output.
        die();
    }
    add_action('wp_ajax_'.'engagebay_wc_ajax', 'engagebay_wc_ajax_callback');
    add_action('wp_ajax_nopriv_'.'engagebay_wc_ajax', 'engagebay_wc_ajax_callback');
}
