<?php

function engagebay_wc_sync_contact($contact)
{
    $engagebay_wc_rest_api_key = get_option('engagebay_wc_settings_rest_api');

    $contact_properties = array(
                            array(
                                'name' => 'name',
                                'value' => $contact['first_name'],
                                'field_type' => 'TEXT',
                                'is_searchable' => false,
                                'type' => 'SYSTEM',
                                ),
                            array(
                                'name' => 'last_name',
                                'value' => $contact['last_name'],
                                'field_type' => 'TEXT',
                                'is_searchable' => false,
                                'type' => 'SYSTEM',
                                ),
                            array(
                                'name' => 'email',
                                'value' => $contact['email'],
                                'field_type' => 'TEXT',
                                'is_searchable' => false,
                                'type' => 'SYSTEM',
                                ),
                            array(
                                'name' => 'phone',
                                'value' => $contact['phone'],
                                'field_type' => 'TEXT',
                                'is_searchable' => false,
                                'type' => 'SYSTEM',
                                'subtype' => 'work',
                                ),
                            array(
                                'name' => 'address',
                                'value' => $contact['address'],
                                'field_type' => 'TEXT',
                                'is_searchable' => false,
                                'type' => 'SYSTEM',
                                ),
                            );

    $tags = array(
                array('tag' => 'WooCommerce'),
                array('tag' => $contact['role']),
                array('tag' => enagagebay_wc_woocommerce_domain()),
                 );

    $bodyData = array('score' => 10, 'company_name' => $contact['company_name'], 'properties' => $contact_properties, 'tags' => $tags);

    $engagebay_rest_url = 'https://app.engagebay.com/dev/api/panel/subscribers/getByEmail/'.$contact['email'];
    $headers = array(
        'Authorization' => $engagebay_wc_rest_api_key,
        'Content-type' => 'application/json',
        'Accept' => 'application/json',
    );

    $args_get = array(
        'method' => 'GET',
        'timeout' => 120,
        'sslverify' => false,
        'headers' => $headers,
    );

    $request = wp_remote_get($engagebay_rest_url, $args_get);
    $search_result = wp_remote_retrieve_body($request);
    $search_result = json_decode($search_result, false, 512, JSON_BIGINT_AS_STRING);

    $headers = array(
        'Authorization' => $engagebay_wc_rest_api_key,
        'Content-type' => 'application/json',
        'Accept' => 'application/json',
    );

    if (isset($search_result->id)) {
        $engagebay_rest_url = 'https://app.engagebay.com/dev/api/panel/subscribers/update-partial';
        $bodyData['id'] = $search_result->id;
        $bodyData['status'] = 'CONFIRMED';
        $bodyData['properties'][0]['value'] = (isset($contact['first_name']) && $contact['first_name'] == null) ? $search_result->name : $contact['first_name'];
        $bodyData['properties'][1]['value'] = (isset($contact['last_name']) && $contact['last_name'] == null) ? (isset($search_result->lastname) ? $search_result->lastname : '') : $contact['last_name'];
        $args_put = array(
            'method' => 'PUT',
            'timeout' => 120,
            'sslverify' => false,
            'headers' => $headers,
            'body' => json_encode($bodyData),
        );
        $response = wp_remote_request($engagebay_rest_url, $args_put);

        engagebay_wc_add_woocommerce_tag($contact['email']);
    } else {
        $engagebay_rest_url = 'https://app.engagebay.com/dev/api/panel/subscribers/subscriber';
        $args_post = array(
            'method' => 'POST',
            'timeout' => 120,
            'sslverify' => false,
            'headers' => $headers,
            'body' => json_encode($bodyData),
        );
        wp_remote_post($engagebay_rest_url, $args_post);
    }
}

function engagebay_sync_order_details($order)
{
    $engagebay_wc_rest_api_key = get_option('engagebay_wc_settings_rest_api');
    $email = $order['customer_email'];
    $engagebay_rest_url = 'https://app.engagebay.com/dev/api/panel/subscribers/getByEmail/'.$email;
    $headers = array(
        'Authorization' => $engagebay_wc_rest_api_key,
        'Content-type' => 'application/json',
        'Accept' => 'application/json',
    );

    $args_get = array(
        'method' => 'GET',
        'timeout' => 120,
        'sslverify' => false,
        'headers' => $headers,
    );

    $request = wp_remote_get($engagebay_rest_url, $args_get);
    $search_result = wp_remote_retrieve_body($request);
    $search_result = json_decode($search_result, false, 512, JSON_BIGINT_AS_STRING);

    if (isset($search_result->id)) {
        $contact_id = $search_result->id;
        if (!engagebay_wc_add_secondary_email($order['billing_email'], $contact_id)) {
            $engagebay_rest_url = 'https://app.engagebay.com/dev/api/search?q='.$order['billing_email'].'&type=Subscriber';
            $request = wp_remote_get($engagebay_rest_url, $args_get);
            $search_result = wp_remote_retrieve_body($request);
            $search_result = json_decode($search_result, false, 512, JSON_BIGINT_AS_STRING);
            $contact_id = $search_result[0]->id;
            $email = $order['billing_email'];
        }
    } else {
        return;
    }

    $notes = array(
                'subject' => $order['subject'],
                'content' => $order['content'],
                'parentId' => $contact_id,
                );

    $engagebay_rest_url = 'https://app.engagebay.com/dev/api/panel/notes';
    $headers = array(
        'Authorization' => $engagebay_wc_rest_api_key,
        'Content-type' => 'application/json',
        'Accept' => 'application/json',
    );

    $args_post = array(
        'method' => 'POST',
        'timeout' => 120,
        'sslverify' => false,
        'headers' => $headers,
        'body' => json_encode($notes),
    );

    wp_remote_post($engagebay_rest_url, $args_post);
    $products = preg_replace('/[^a-zA-Z0-9_.,]/', '_', fn_js_escape($order['products']));
    $tags = '['.$products.']';
    $engagebay_rest_url = 'https://app.engagebay.com/dev/api/panel/subscribers/email/tags/add';
    $headers = array(
        'Authorization' => $engagebay_wc_rest_api_key,
        'Content-type' => 'application/x-www-form-urlencoded',
        'Accept' => 'application/json',
    );

    $args_post = array(
        'method' => 'POST',
        'timeout' => 120,
        'sslverify' => false,
        'headers' => $headers,
        'body' => 'email='.$email.'&tags='.$tags,
    );

    wp_remote_post($engagebay_rest_url, $args_post);

    return;
}

function engagebay_is_user_synced($email)
{
    $engagebay_wc_rest_api_key = get_option('engagebay_wc_settings_rest_api');
    $engagebay_rest_url = 'https://app.engagebay.com/dev/api/panel/subscribers/getByEmail/'.$email;
    $headers = array(
        'Authorization' => $engagebay_wc_rest_api_key,
        'Content-type' => 'application/json',
        'Accept' => 'application/json',
    );

    $args_get = array(
        'method' => 'GET',
        'timeout' => 120,
        'sslverify' => false,
        'headers' => $headers,
    );
    $request = wp_remote_get($engagebay_rest_url, $args_get);

    $search_result = wp_remote_retrieve_body($request);
    $search_result = json_decode($search_result, false, 512, JSON_BIGINT_AS_STRING);

    if (isset($search_result->id)) {
        return true;
    } else {
        return false;
    }
}

function engagebay_wc_add_woocommerce_tag($email)
{
    $engagebay_wc_rest_api_key = get_option('engagebay_wc_settings_rest_api');
    $engagebay_rest_url = 'https://app.engagebay.com/dev/api/panel/subscribers/email/tags/add';

    $headers = array(
        'Authorization' => $engagebay_wc_rest_api_key,
        'Content-type' => 'application/x-www-form-urlencoded',
        'Accept' => 'application/json',
    );
    $args_post = array(
            'method' => 'POST',
            'timeout' => 120,
            'sslverify' => false,
            'headers' => $headers,
            'body' => 'email='.$email.'&tags=["WooCommerce"]',
        );
    wp_remote_post($engagebay_rest_url, $args_post);

    return;
}

function engagebay_wc_add_secondary_email($secondary_email, $contact_id)
{
    $contact_properties = array(
        array(
            'name' => 'email',
            'value' => $secondary_email,
            'field_type' => 'TEXT',
            'is_searchable' => false,
            'type' => 'SYSTEM',
            'subtype' => 'secondary',
            ),
        );

    $headers = array(
        'Authorization' => get_option('engagebay_wc_settings_rest_api'),
        'Content-type' => 'application/json',
        'Accept' => 'application/json',
    );

    $bodyData = array('score' => 10, 'properties' => $contact_properties);
    $engagebay_rest_url = 'https://app.engagebay.com/dev/api/panel/subscribers/update-partial';
    $bodyData['id'] = $contact_id;
    $args_put = array(
            'method' => 'PUT',
            'timeout' => 120,
            'sslverify' => false,
            'headers' => $headers,
            'body' => json_encode($bodyData),
        );
    $response = wp_remote_request($engagebay_rest_url, $args_put);

    if (is_array($response) && (strpos($response['body'], 'already exists') !== false)) {
        return false;
    }

    return true;
}

function fn_js_escape($str)
{
    return strtr($str, array('\\' => '\\\\',  "'" => "\\'", '"' => '\\"', "\r" => '\\r', "\n" => '\\n', "\t" => '\\t', '</' => '<\/', '/' => '\\/'));
}

function engagebay_wc_endpoint($batch, $type)
{
    $engagebay_wc_rest_api_key = get_option('engagebay_wc_settings_rest_api');
    $engagebay_rest_url = 'https://app.engagebay.com/dev/api/panel/woocommerce/bulk-dump/'.$type;

    $headers = array(
        'Authorization' => $engagebay_wc_rest_api_key,
        'Content-type' => 'application/json',
        'Accept' => 'application/json',
    );
    $args_post = array(
            'method' => 'POST',
            'timeout' => 120,
            'sslverify' => false,
            'headers' => $headers,
            'body' => json_encode($batch),
        );
    $response = wp_remote_post($engagebay_rest_url, $args_post);

    $response = wp_remote_retrieve_body($response);
    $response = json_decode($response, false, 512, JSON_BIGINT_AS_STRING);
}
